@@ -1,15 +1,16 @@
-"LLTM" <-
-function(X,W,mpoints=1,Groups=1)
+`LLTM` <-
+function(X,W,mpoints=1,groupvec=1)
 {
 #...X: person*(item*times) matrix (T1|T2|...)
 #library("gtools")
 model <- "LLTM"
 if (missing(W)) W <- NA
+else W <- as.matrix(W)
 
 XWcheck <- datcheck(X,W)                              #inital check of X and W
 X <- XWcheck$X
 
-lres <- likLR(X,W,mpoints,Groups,model)
+lres <- likLR(X,W,mpoints,groupvec,model)
 likall <- lres$likall[[1]]
 LR <- lres$LR 
                               
@@ -19,9 +20,9 @@ etapar <- likall[[1]]$estimate                         #eta estimates
 se <- sqrt(diag(solve(likall[[1]]$hessian)))           #standard errors
 betapar <- as.vector(lres$W%*% etapar)                 #beta estimates
 
-result <- list(loglik=loglik,iter=iter,etapar=etapar,se_eta=se,betapar=betapar,
-               LR=LR,likall=likall,W=lres$W,mpoints=mpoints,ngroups=max(Groups))
-class(result) <- c("Rm","eRm")                         #classes: simple RM and extended RM
+result <- list(model=model,loglik=loglik,df=dim(lres$W)[2],iter=iter,etapar=etapar,se_eta=se,hessian=likall[[1]]$hessian,betapar=betapar,
+               LR=LR,W=lres$W,mpoints=mpoints,ngroups=max(groupvec))
+class(result) <- "eRm"                         #classes: simple RM and extended RM
 result
 }
 
