@@ -1,20 +1,19 @@
-"PCM" <-
+`PCM` <-
 function(X,W)
 {
 #...X: person*item scores matrix (starting from 0)
 
 #-------------------main programm-------------------
-#library("gtools")
 model <- "PCM"
 Groups <- 1
 mpoints <- 1
 if (missing(W)) W <- NA
+else W <- as.matrix(W)
 
 XWcheck <- datcheck(X,W)                              #inital check of X and W
 X <- XWcheck$X
 
 lres <- likLR(X,W,mpoints,Groups,model)
-likall123 <- lres$likall
 likall <- lres$likall[[1]]
 LR <- lres$LR
                                 
@@ -24,9 +23,17 @@ etapar <- likall[[1]]$estimate                         #eta estimates
 se <- sqrt(diag(solve(likall[[1]]$hessian)))           #standard errors
 betapar <- as.vector(lres$W%*% etapar)                 #beta estimates
 
-result <- list(loglik=loglik,iter=iter,etapar=etapar,se_eta=se,betapar=betapar,
-               LR=lres$LR,likall=likall,W=lres$W,likall123=likall123,G=lres$G,
-               mpoints=mpoints,ngroups=max(Groups))
+if (length(LR)>1) {
+  etaparG1 <- lres$likall[[2]][[1]]$estimate             #parameter vector group1 in LR-test (needed for plot method)
+  etaparG2 <- lres$likall[[3]][[1]]$estimate             #parameter vector group2 
+} else {
+  etaparG1 <- NA
+  etaparG2 <- NA
+}
+
+result <- list(model=model,loglik=loglik,df=dim(lres$W)[2],iter=iter,etapar=etapar,se_eta=se,hessian=likall[[1]]$hessian,betapar=betapar,
+               LR=lres$LR,W=lres$W,etaparG1=etaparG1,etaparG2=etaparG2)
+
 class(result) <- c("Rm","eRm")                         #classes: simple RM and extended RM
 result
 }
